package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````P"4```````!``````````$"S````
M`````````$``.``+`$``'0`<``8````$````0`````````!``````````$``
M````````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"````````J`(````````<`````````!P``````````0`````````!````
M!````````````````````````````````````'`<````````<!P`````````
M$`````````$````%`````"``````````(``````````@````````[3X`````
M``#M/@`````````0`````````0````0`````8`````````!@`````````&``
M```````010```````!!%`````````!`````````!````!@```)"M````````
MD+T```````"0O0```````&`$````````"!4`````````$`````````(````&
M````H*T```````"@O0```````*"]````````(`(````````@`@````````@`
M````````!`````0```#$`@```````,0"````````Q`(```````!$````````
M`$0`````````!`````````!0Y71D!````("=````````@)T```````"`G0``
M``````0!````````!`$````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``"0K0```````)"]````````D+T```````!P`@```````'`"`````````0``
M```````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`!````!0````#````
M1TY5`&,4:]8)JHW?;I2=O7AF-)9)"!OG!````!`````!````1TY5```````#
M`````@````````!#````80``````````````5P```#`````]````.@``````
M``!+`````````#D````[````/@```#4```!6````4P```!X````G````````
M``````!?```````````````O````!P```$P````7````30```%X````H````
M20``````````````60````````!$````+@```%P`````````1P```#0`````
M````(@`````````I````70```!`````,````6@````````!%`````````"4`
M````````6P```#,````W````(0`````````R````.````$\````V````)```
M`#\````\````*@```$$`````````````````````````0@``````````````
M``````(``````````````````````````0````````!4````"@``````````
M``````````````!8````````````````````"0````T``````````````$``
M````````$@````\`````````&0````L``````````````%4````?````'0``
M`",``````````````!$`````````(````$8`````````"````$,````M````
M2````"L```!1````&P```%(````Q`````````%`````L````$P````0`````
M````%````&``````````&````$X``````````````````````````````!4`
M```F````2@````,````&```````````````:````'```````````````````
M````````````!0``````````````````````````````%@`````````.````
M$0```#\````$````"````"`<$``%0`2&*`)`!)"&`(2""0`@22`$"+BB$46Z
M``(*`````#\```!"````10```$8```!-````3@```%````!4````50```%<`
M``!8````6P```%T```!?``````````````!NQ=\?SMY'+6M_FGPNQ9NV(/_D
M#M5DU'S9<5@<XD?&`4+ZUX>L2^/`NN.2?,+E/RSZH6Q@LP&+;VL)0]9FK\QF
MQ;F<0$)%U>S$B060B`=PTSGRBQP-%.*>VLWCGC-BV^T5C"7,##J7"U:DFY:G
MW:-K?JF<F]%ESFW@IP(*:QJ>4`J*$%>CX/M)````````````````````````
M`````````````$$"```2`````````````````````````"$!```2````````
M`````````````````)H````2`````````````````````````$\````2````
M`````````````````````&$!```@`````````````````````````!L!```2
M`````````````````````````,4````2`````````````````````````.4`
M```2`````````````````````````*4"```2````````````````````````
M`)`````2`````````````````````````&D````2````````````````````
M`````-0!```2`````````````````````````$H#```2````````````````
M`````````#P"```2`````````````````````````*H````2````````````
M`````````````'L````2`````````````````````````#0````2````````
M``````````````````@!```2`````````````````````````/,````2````
M`````````````````````)<"```2`````````````````````````&4"```2
M`````````````````````````-,"```2`````````````````````````%L!
M```2`````````````````````````*$````2````````````````````````
M`"(````2`````````````````````````,`"```2````````````````````
M`````,X````2`````````````````````````%8!```2````````````````
M`````````!`````2``````````````````````````$!```2````````````
M`````````````',"```2`````````````````````````'T!```@````````
M`````````````````.P````2`````````````````````````+0!```2````
M`````````````````````-X"```2`````````````````````````,P"```2
M`````````````````````````.,!```2`````````````````````````.\!
M```2`````````````````````````(P"```2````````````````````````
M`%("```2`````````````````````````*8!```2````````````````````
M`````$8"```2`````````````````````````+<````2````````````````
M`````````+4"```2`````````````````````````"`"```2````````````
M`````````````-T````2`````````````````````````$<!```2````````
M`````````````````-4````2`````````````````````````'$````2````
M`````````````````````,,!```2`````````````````````````&(````2
M`````````````````````````/H````2``````````````````````````0"
M```2`````````````````````````(,"```2````````````````````````
M`%<````2`````````````````````````!8!```2````````````````````
M`````$X!```2`````````````````````````#D!```2````````````````
M`````````(P!```@`````````````````````````+`````2````````````
M``````````````\!```2`````````````````````````((````2````````
M`````````````````%,#```2``\`8$X````````^`0```````'\#```2``\`
M0%,```````!G"````````!T````2``\`L",````````/`@```````"<#```2
M``\`($4````````%`````````!,$```2``\`,$4````````2`@```````$D$
M```2``\`L%L```````"=`@```````/\#```0`!H`\,$`````````````````
M`&8#```2``\`4$<````````E`````````(P#```2``\`H$\```````"?`0``
M`````*0#```1`!$``&`````````$`````````.,#```0`!H`F-(`````````
M``````````L$```2``\`$$0````````P`````````"`$```2``\`\$P`````
M```+`0```````#($```2``\`4$P```````!T`````````)<#```0`!D`T,$`
M`````````````````',#```2``\`@$<````````<`````````$4````1`!H`
M(,(````````(`````````%\#```0`!D`\,$``````````````````$8````A
M`!H`(,(````````(`````````-D#```1`!D`Z,$````````(`````````#(!
M```1`!H`0,(````````(`````````!<#```2``\`P%X````````%````````
M`,D#```2``\`4%X```````!E`````````)T#```2``\`P"4````````O````
M`````$`$```2``\``$X```````!4`````````)D#```@`!D`T,$`````````
M`````````#$"```1`!H``,(````````$`````````$<````A`!H`(,(`````
M```(`````````#@#```2``\`T$P````````=``````````$````B````````
M`````````````````+,#```2``\`0$0```````#4`````````/4#```2``\`
M0%$```````#[`0```````!,"```1`!H`$,(````````!`````````.@#```2
M``\`H$<```````"F!`````````!?7V-X85]F:6YA;&EZ90!?7VQI8F-?<W1A
M<G1?;6%I;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]F86EL`%]?
M96YV:7)O;@!S=')N8VUP`%]?;'AS=&%T-C0`86-C97-S`&]P96YD:7(`<F5A
M9&1I<C8T`'-T<FQE;@!?7W-P<FEN=&9?8VAK`%]?>'-T870V-`!U;FQI;FL`
M8VQO<V5D:7(`<FUD:7(`<W1R9'5P`%]?<W1R;F-P>5]C:&L`<F5A9&QI;FL`
M;65M8VAR`&UE;6UO=F4`<F5A;&QO8P!G971P:60`;65M8W!Y`'-T<F-H<@!S
M=')T;VL`<W1R8VUP`&=E='5I9`!S=')S='(`97AI=`!M:V1I<@!?7V5R<FYO
M7VQO8V%T:6]N`'-T9&5R<@!?7V9P<FEN=&9?8VAK`&]P96XV-`!L<V5E:S8T
M`')E860`8VQO<V4`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?9VUO
M;E]S=&%R=%]?`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?
M=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N
M<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?
M<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H
M<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C
M:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L
M7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R
M<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`<'1H<F5A9%]G971S
M<&5C:69I8P!L:6)P97)L+G-O`&QI8G!T:')E860N<V\N,`!L:6)C+G-O+C8`
M7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE
M7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7V5D871A`'!A<E]B87-E;F%M
M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`<VAA7W5P9&%T90!?7V1A=&%?
M<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?
M;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`7V5N9`!P87)?:6YI=%]E;G8`<VAA
M7V9I;F%L`%]?8G-S7W-T87)T`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S
M971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`<VAA7VEN:70`6%-?26YT97)N
M86QS7U!!4E]"3T]4`$=,24)#7S(N,BXU`$=,24)#7S(N,RXT`$=,24)#7S(N
M,30`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXT`"]U<W(O;&EB+W!E<FPU+S4N,S(N
M,"]X.#9?-C0M;&EN=7@M=&AR96%D+6UU;'1I+T-/4D4``````@`"``(``@``
M``(``@`"`````@`"`````@````(``@`#``(``@`````````"``(`!`````(`
M`@`"``(```````4````&``(`````````````````!P```````@`"``(``@``
M``(``@```````@`"``(`!P````(``@`'``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``@`!``(``0`"``$``0`!``$``0````(``0`"``$``0``
M``$``0`!`/T"```0````(````'4::0D```8`7P0````````!``4`#0,``!``
M````````=!EI"0``!P!K!```$````)21E@8```4`=P0``!````!R&6D)```$
M`(($```0````%&EI#0```P".!```$````'4::0D```(`7P0```````"0O0``
M``````@`````````H"8```````"8O0````````@`````````8"8```````#8
MP0````````@`````````V,$```````#HP0````````@`````````X&(`````
M``#`OP````````8````%``````````````#(OP````````8````)````````
M``````#0OP````````8````=``````````````#8OP````````8````@````
M``````````#@OP````````8````H``````````````#HOP````````8````R
M``````````````#POP````````8````[``````````````#XOP````````8`
M``!<````````````````P@````````4```!9```````````````0P@``````
M``4```!?```````````````@P@````````4```!/``````````````!`P@``
M``````4```!3```````````````8P`````````<````!```````````````@
MP`````````<````"```````````````HP`````````<````#````````````
M```PP`````````<````$```````````````XP`````````<````&````````
M``````!`P`````````<````'``````````````!(P`````````<````(````
M``````````!0P`````````<````*``````````````!8P`````````<````+
M``````````````!@P`````````<````,``````````````!HP`````````<`
M```-``````````````!PP`````````<````.``````````````!XP```````
M``<````/``````````````"`P`````````<````0``````````````"(P```
M``````<````1``````````````"0P`````````<````2``````````````"8
MP`````````<````3``````````````"@P`````````<````4````````````
M``"HP`````````<````5``````````````"PP`````````<````6````````
M``````"XP`````````<````7``````````````#`P`````````<````8````
M``````````#(P`````````<````9``````````````#0P`````````<````:
M``````````````#8P`````````<````;``````````````#@P`````````<`
M```<``````````````#HP`````````<````>``````````````#PP```````
M``<````?``````````````#XP`````````<````A````````````````P0``
M``````<````B```````````````(P0````````<````C```````````````0
MP0````````<````D```````````````8P0````````<````E````````````
M```@P0````````<````F```````````````HP0````````<````G````````
M```````PP0````````<````I```````````````XP0````````<````J````
M``````````!`P0````````<````K``````````````!(P0````````<````L
M``````````````!0P0````````<````M``````````````!8P0````````<`
M```N``````````````!@P0````````<````O``````````````!HP0``````
M``<````P``````````````!PP0````````<````Q``````````````!XP0``
M``````<````S``````````````"`P0````````<````T``````````````"(
MP0````````<````U``````````````"0P0````````<````V````````````
M``"8P0````````<````W``````````````"@P0````````<````X````````
M``````"HP0````````<````Y``````````````"PP0````````<````Z````
M``````````"XP0````````<````\``````````````#`P0````````<````]
M``````````````#(P0````````<````^````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!<F?``!(A<!T`O_02(/$",,``````/\UXI\``/\EY)\`
M``\?0`#_)>*?``!H`````.G@_____R7:GP``:`$```#IT/____\ETI\``&@"
M````Z<#_____)<J?``!H`P```.FP_____R7"GP``:`0```#IH/____\ENI\`
M`&@%````Z9#_____);*?``!H!@```.F`_____R6JGP``:`<```#I</____\E
MHI\``&@(````Z6#_____)9J?``!H"0```.E0_____R62GP``:`H```#I0/__
M__\EBI\``&@+````Z3#_____)8*?``!H#````.D@_____R5ZGP``:`T```#I
M$/____\E<I\``&@.````Z0#_____)6J?``!H#P```.GP_O___R5BGP``:!``
M``#IX/[___\E6I\``&@1````Z=#^____)5*?``!H$@```.G`_O___R5*GP``
M:!,```#IL/[___\E0I\``&@4````Z:#^____)3J?``!H%0```.F0_O___R4R
MGP``:!8```#I@/[___\E*I\``&@7````Z7#^____)2*?``!H&````.E@_O__
M_R4:GP``:!D```#I4/[___\E$I\``&@:````Z4#^____)0J?``!H&P```.DP
M_O___R4"GP``:!P```#I(/[___\E^IX``&@=````Z1#^____)?*>``!H'@``
M`.D`_O___R7JG@``:!\```#I\/W___\EXIX``&@@````Z>#]____)=J>``!H
M(0```.G0_?___R72G@``:"(```#IP/W___\ERIX``&@C````Z;#]____)<*>
M``!H)````.F@_?___R6ZG@``:"4```#ID/W___\ELIX``&@F````Z8#]____
M):J>``!H)P```.EP_?___R6BG@``:"@```#I8/W___\EFIX``&@I````Z5#]
M____)9*>``!H*@```.E`_?___R6*G@``:"L```#I,/W___\E@IX``&@L````
MZ2#]____)7J>``!H+0```.D0_?___R5RG@``:"X```#I`/W___\E:IX``&@O
M````Z?#\____)6*>``!H,````.G@_/___R5:G@``:#$```#IT/S___\E4IX`
M`&@R````Z<#\____)4J>``!H,P```.FP_/___R5"G@``:#0```#IH/S___\E
M.IX``&@U````Z9#\____)3*>``!H-@```.F`_/___R52G```9I``````````
M`$%454B#[#B)?"0<2(U\)!Q(B70D$$B-="002(E4)`A(C50D"&1(BP0E*```
M`$B)1"0H,<#H%_[__TB+-?";``!(BSWQFP``2(GRZ-$Z``"`/0J>````=2_H
M4_W__TB)!6RN``!(B<=(A<`/A)`!``#HF_S__XL]U9T``.C@_?__QH#I"0``
M`(L]PYT``.C._?__BSVXG0``@(@Z!````NB\_?__@(@Z!````8M$)!R->`1$
MC6`#2&/_2,'G`^@N_?__2(M,)!"+="0<28G!2(D%"ZX``$B+`4F)`4B-!:H\
M``!)B4$(2(L%2YT``$F)01!(C067/```28E!&(/^`0^.\0```$B#P0B#Q@.X
M!`````\?@`````!(BSE(8]"#P`%(@\$(28D\T3G&=>M(8_9(P>8#2(L]E:T`
M`$2)XD4QP$R)R4G'!#$`````2(TUK1H``.B(_?__08G$A<!T4TB+/6JM``!(
MC6PD).@@_/__,<!(B>Y(C3UW.P``Z)\7``!(A<!T/4B+/4.M``#HGOO__^@9
M_?__2(M$)"AD2"L$)2@```!U8TB#Q#A$B>!=05S#2(L]%ZT``.BR_?__08G$
MZYQ(BST.K0``2(7_=`?HW"@``.NP2(T]S3H``$B)[N@[%P``2(D%[*P``$B)
MQTB%P'22Z]F^(````.DT____OP$```#HAOW__^A1^___D/,/'OHQ[4F)T5Y(
MB>)(@^3P4%1,C07F.```2(T-;S@``$B-/<C]____%>*9``#TD$B-/?F;``!(
MC07RFP``2#GX=!5(BP6VF0``2(7`=`G_X`\?@`````###Q^``````$B-/<F;
M``!(C37"FP``2"G^2(GP2,'N/TC!^`-(`<9(T?YT%$B+!:69``!(A<!T"/_@
M9@\?1```PP\?@`````#S#Q[Z@#W=FP```'4K54B#/8*9````2(GE=`Q(BSU6
MFP``Z!G]___H9/___\8%M9L```%=PP\?`,,/'X``````\P\>^NEW____#Q^`
M`````$%73(U/.$%6055!5%532('LF`(``&1(BP0E*````$B)A"2(`@``,<!(
MB>),C90D@````$F)T&8N#Q^$``````!!BP%)BS%)@\`028/!"`_(B<!(B?%)
MB4#P2(GP2,'I($C!Z"A(P>XX)0#_``!("?!(B<Y(P>$(2,'F&('A``#_`(GV
M2`GP2`G(28E`^$TYT'6N2(VR``(```\?@`````!(BT)H2#-"0$B#P@A(,T((
M2#-"^$B-#`!(P>@?2`G(@^#_2(E">$@Y\G753(L/3(M?$$B+=R!(BU\83(G(
M3(G*2(MO"$C!ZAM(P>`%2`G0`P0DC90PF7F"6DR)V$B+="0(2#'82"'H2(VT
M,YEY@EI(,=A$C10"2(GJ2(GH2,'H`DC!XAY-B=!("<),B=A)P>@;B=%(,<A,
M(<A,,=A(`?!,B=9(P>8%3`G&1(TT,$R)SDR)R$C!YAY(P>@"38GP2`GP2(MT
M)!!)P>@;2#'"08G%3"'228VT,YEY@EI(,<I(`?),B?9(P>8%3`G&1(T$,DR)
MUDG!Z@)(BU0D&$C!YAY,"=9(C901F7F"6DR)P4@Q\$&)]$PA\$PQZ$C!Z1M(
M`=!,B<)(P>(%2`G*3(GQ2<'N`DC!X1Y$C1002(GP2(M4)"!,"?%,B=9(,<A)
MC905F7F"6DC![AM!B<Y,(<!,,>!(`=!,B=)(P>(%2`GR1(TL$$R)PDG!Z`)(
MBT0D*$C!XAY,B>Y,"<))C80$F7F"6DC![AM(,=%!B=!,(=%,,?%(`<%,B>A(
MP>`%2`GP1(TD`4R)T$G!Z@)(BTPD,$C!X!Y,B>9,"=!)C8P.F7F"6D@QPD&)
MPDPAZDPQPD@!RDR)X4C!X05(P>X;2`GQ3(GN2<'M`DC!YAY$C30*2(M4)#A,
M">Y,B?%(,?!)C900F7F"6DC!Z1M!B?5,(>!,,=!(`=!,B?)(P>(%2`G*3(GA
M2<'L`DC!X1Y$C0002(GP2(M4)$!,">%,B<9(,<A)C902F7F"6DC![AM!B<Q,
M(?!,,>A(`=!,B<)(P>(%2`GR1(T4$$R)\DG![@)(BT0D2$C!XAY,B=9,"?))
MC80%F7F"6DC![AM(,=%!B=9,(<%,,>%(`<%,B=!(P>`%2`GP1(TL`4R)P$G!
MZ`)(BTPD4$C!X!Y,B>Y,"<!)C8P,F7F"6DC![AM(,<)!B<!,(=),,?)(`<I,
MB>E(P>$%2`GQ3(G62<'J`DC!YAY$C20*2(M4)%A,"=9,B>%(,?!)C906F7F"
M6DC!Z1M!B?),(>A,,<!(`=!,B>)(P>(%2`G*3(GI2<'M`DC!X1Y$C3002(GP
M2(M4)&!,">E,B?9(,<A)C900F7F"6DC![AM!B<U,(>!,,=!(`=!,B?)(P>(%
M2`GR1(T$$$R)XDB+1"1H2,'B'DG![`),B<9,">))C80"F7F"6DC![AM(,=%!
MB=1,(?%,,>E(`<%,B<!(P>`%2`GP1(T4`4R)\$G![@)(BTPD<$C!X!Y,B=9,
M"?!)C8P-F7F"6DC![AM(,<)!B<9,(<),,>)(`<I,B=%(P>$%2`GQ3(G&2<'H
M`DC!YAY$C2P*2(M4)'A,"<9,B>E(,?!)C904F7F"6DC!Z1M!B?!,(=!,,?!(
M`=!,B>I(P>(%2`G*3(G12<'J`DC!X1Y$C2002(GP2(N4)(````!,"=%,B>9(
M,<A)C906F7F"6DC![AM!B<I,(>A,,<!(`=!,B>)(P>(%2`GR1(TT$$R)ZDG!
M[0)(BX0DB````$C!XAY,B?9,">I)C80`F7F"6DC![AM(,=%!B=5,(>%,,=%(
M`<%,B?!(P>`%2`GP1(T$`4R)X$G![`)(BXPDD````$C!X!Y,">!)C8P*F7F"
M6DV)PD@QPDG!ZAN)QDPA\DPQZD@!RDR)P4C!X05,"=%-B?))P>X"2<'B'HG)
M30GR2`'*2(N,))@```!,,=!!B=1,(<!)C8P-F7F"6DV)Y4@Q\$G![1M(`<A,
MB>%(P>$%3`GIB<E(`<A,B<%)P>@"2,'A'D&)Q4P)P4V)T$6)TDP#E"2H````
M23'(1#'"3(N$)*````!.C80&H>O9;DR)[DD!T$R)ZDC![AM(P>(%2`GRB=))
M`=!,B>))P>P"2,'B'D2)QDP)XDF)S(G)2`.,)+````!),=1$,>!)B?1-C90"
MH>O9;DB)\$G![!M(P>`%3`G@B<!)`<),B>A)P>T"2,'@'D6)U$P)Z$F)U8G2
M23'%13'H38GE2`.4)+@```!.C80!H>O9;DR)X4G![1M(P>$%3`GIB<E,`<%)
MB?!(P>X"2<'@'D&)S4D)\$B)QHG`2`.$),````!,,<9!,?)*C;02H>O9;DR)
MZDV)ZDG!ZAM(P>(%3`G2B=)(`?),B>9)P>P"2,'F'D&)TDP)YDV)Q$6)P$P#
MA"3(````23'T1#'A38G42(V,"*'KV6Y,B=!)P>P;2,'@!4P)X(G`2`'(3(GI
M2<'M`DC!X1Y!B<1,">E)B?6)]DDQS40QZDV)Y4V-A!"AZ]EN3(GB2,'B!4G!
M[1M(`[0DT````$P)ZHG220'03(G22<'J`DC!XAY%B<5,"=))B<J)R4@#C"38
M````23'21#'038GJ2(VT!J'KV6Y,B>A)P>H;2,'@!4P)T(G`2`'&3(G@2<'L
M`DC!X!Y!B?),">!)B=2)TD@#E"3@````23'$13'@38G43HV$`:'KV6Y,B=%)
MP>P;2,'A!4P)X8G)3`'!38GH2<'M`DG!X!Y!B<Q-">A)B<6)P$TQQ40Q[DV)
MY4B-M#*AZ]EN3(GB2<'M&TC!X@5,">J)TD@!\DR)UDG!Z@)(`X0DZ````$C!
MYAY!B=5,"=9-B<)%B<!,`X0D\````$DQ\D0QT4V)ZDB-C`BAZ]EN3(GH2<'J
M&TC!X`5,"=")P$@!R$R)X4G![`)(P>$>08G"3`GA28GTB?9(`[0D^````$DQ
MS$0QXDV)U$V-A!"AZ]EN3(G22<'L&TC!X@5,">*)TDD!T$R)ZDG![0)(P>(>
M18G$3`GJ28G-B<E),=5$,>A-B>5(C;0&H>O9;DR)X$G![1M(P>`%3`GHB<!(
M`<9,B=!(P>`>2<'J`D&)]4@#C"0``0``3`G028G2B=)(`Y0D"`$``$DQPD4Q
MT$V)ZDZ-A`&AZ]EN3(GI2<'J&TC!X05,"=&)R4P!P4V)X$G![`))P>`>08G*
M30G@28G$B<!(`X0D$`$``$TQQ$0QYDV)U$B-M#*AZ]EN3(G22<'L&TC!X@5,
M">*)TD@!\DR)[DG![0)(P>8>08G43`GN38G%18G`23'U1#'I38GE2(V,"*'K
MV6Y,B>!)P>T;2,'@!4P)Z(G`2`'(3(G12<'J`DC!X1Y!B<5,"=%)B?),`X0D
M&`$``(GV23'*2`.T)"`!``!$,=)-C;00H>O9;DR)ZDV)Z$G!Z!M(P>(%3`G"
M28G(B<E(`XPD*`$``(G220'63(GB2<'L`DC!XAY%B?),">)),=!$,<!,C:0&
MH>O9;DR)T$R)UDC![AM(P>`%2`GP2(G6B=)(`Y0D,`$``(G`20'$3(GH2<'M
M`DC!X!Y%B>!,">A(,<9!,?9,B<9.C:PQH>O9;DR)P4C![AM(P>$%2`GQB<E)
M`<U,B=%)P>H"2,'A'D2)[DP)T4F)PHG`23'*13'42`.$)#@!``!.C90BH>O9
M;DB)\DF)]$G![!M(P>(%3`GB38G$2<'H`DG!Y!Y!`=)-"<1)B<B)R4TQX$2)
MXD4QQ4Z-A"BAZ]EN3(G038G52<'M&TC!X`5,">A,BZPD0`$``$6--`!)B?!(
MP>X"3(G@2<'@'DD)\$2)QDP)P$PAT$DA]$D)Q+C<O!N/20'%3`'I38GU3`'A
M38GT2<'M&TG!Y`5-">Q!`<Q,B=%)P>H"2,'A'DP)T4D)R$F)S4&)RDTA\$DA
M]4T)Z$R+K"1(`0``20'%3`'J38GE20'03(GB2<'M&TC!X@5,">I%C2P03(GR
M2<'N`DC!XAY,"?))B<Y!B=!)"=9-(>9,(<%,"?%,B[0D4`$``$D!QDP!]DV)
M[D@!\4R)[DG![AM(P>8%3`GV1(TT,4R)YDG![`)(P>8>3`GF2`GR28GTB?%-
M(<1,(>I,">),BZ0D6`$``$D!Q$T!XDV)]$P!TDV)\DG!X@5)P>P;30GB1HTD
M$DV)ZDG![0))P>(>30GJ28GU1(G230G532'U2"'63`GN3(NL)&`!``!)`<5-
M`>A-B>5,`<9-B>!)P>T;2<'@!4T)Z$:-+`9-B?!)P>X"2<'@'DT)\$T)PDV)
MQD2)QDDAUDTAXDT)\DR+M"1H`0``20'&3`'Q38GN20'*3(GI2<'N&TC!X05,
M"?%%C30*3(GA2<'L`DC!X1Y,">%-B<1)"<Q!B<I-(>Q-(=!-">!,BZ0D<`$`
M`$D!Q$P!XDV)]$D!T$R)\DG![!M(P>(%3`GB18TD$$R)ZDG![0)(P>(>3`GJ
M2`G128G508G032'53"'Q3`GI3(NL)'@!``!)`<5,`>Y-B>5(`?%,B>9)P>T;
M2,'F!4P)[D2-+#%,B?9)P>X"2,'F'DP)]DF)UHGQ20GV32'F2"'*3`GR3(NT
M)(`!``!)`<9-`?)-B>Y,`=)-B>I)P>X;2<'B!4T)\D:--!)-B>))P>P"2<'B
M'DT)XDP)UDV)U$2)TDDAS$PA[DP)YDR+I"2(`0``20'$30'@38GT3`'&38GP
M2<'L&TG!X`5-">!&C20&38GH2<'M`DG!X!Y-">A-B=5$B<9-"<5-(?5)(?)-
M">I,BZPDD`$``$D!Q4P!Z4V)Y4D!RDR)X4G![1M(P>$%3`GI18TL"DR)\4G!
M[@)(P>$>3`GQ20G(28G.08G*22'V32'@30GP3(NT))@!``!)`<9,`?)-B>Y)
M`=!,B>I)P>X;2,'B!4P)\D6--!!,B>))P>P"2,'B'DP)XDF)S$&)T$D)U$TA
M[$PAP4P)X4R+I"2@`0``20'$3`'F38GT2`'Q3(GV2<'L&TC!Y@5,">9$C20Q
M3(GN2<'M`DC!YAY,">Y("?))B?6)\4TAQ4PA\DP)ZDR+K"2H`0``20'%30'J
M38GE3`'238GB2<'M&TG!X@5-">I&C2P238GR2<'N`DG!XAY-"?))B?9$B=)-
M"=9-(>9((=9,"?9,B[0DL`$``$D!QDT!\$V)[DP!QDV)Z$G![AM)P>`%30GP
M1HTT!DV)X$G![`))P>`>30G@30G"38G$1(G&22'432'J30GB3(ND)+@!``!)
M`<1,`>%-B?1)`<I,B?%)P>P;2,'A!4P)X46-)`I,B>E(P>$>2<'M`DP)Z4V)
MQ4&)RDD)S4TA]4TAT$T)Z$R+K"3``0``20'%3`'J38GE20'03(GB2<'M&TC!
MX@5,">I%C2P03(GR2<'N`DC!XAY,"?)("=%)B=!!B==-(=!,(>%,"<%,BX0D
MR`$``$D!P$P!QDV)Z$@!\4R)[DG!Z!M(P>8%3`G&1(T$,4R)YDG![`)(B=%(
MP>8>3`GF08GT2`GQ3"'I3"'B2`G*2(N,)-`!``!(`<%(`X0DV`$``$D!RDR)
MP4D!QTP!TDV)PDC!X05)P>H;3`G1B<E(`<I,B>E)P>T"2,'A'D&)TDP)Z4R)
MT$@)SDF)S4C!X`5!B<Y-(>5,(<9,">Y-B=5)P>T;3`'^3`GHB<!(`<9,B<!)
MP>@"2,'@'D&)]4D)P+C6P6+*3#'!,<I(BXPDX`$``$@!P4P!X4V)[$@!T4R)
MZDG![!M(P>(%3`GBB=)(`=%,B=))P>H"2,'B'D&)S$D)TDR)PD6)P$PQTC'6
M2(N4).@!``!(`<))`=9,B>),`?9-B>9(P>(%2<'N&TP)\HG23(TT%DR)ZDG!
M[0),B=9(P>(>18GW18G220G52(N4)/`!``!,,>Y(`<(Q\4R)_DP!PDC![AM(
M`=%,B?I(P>(%2`GR2(NT)/@!``")TD@!T4R)XD@!QDG![`)(P>(>3`'638GJ
M08G(3`GB38G$18GM23'213'63HT4-DR)QDC!Y@5)P>P;3`GFB?9)`?),B?Y)
MP>\"2,'F'D6)U$D)]TB+M"0``@``2`'&3`'N28G5B=)-,?U$,>E,C2P.3(GA
M3(GF2,'N&TC!X05("?%,B<9)P>@"B<E(P>8>20'-2(N,)`@"``!,"<9-B?A)
M,?!%B>Y%B?](`<%%,<)(`<I,B?%.C0023(GR2,'I&TC!X@5("<I(B?&)]HG2
M20'03(GB2<'L`DC!XAY%B<))"=1(BY0D$`(``$PQX4@!PD$QS4R)T4P!^DD!
MU4R)TDC!Z1M(P>(%2`G*3(GQ2<'N`HG22,'A'DD!U4B+E"08`@``3`GQ18GO
M2`'"2`'R3(GF18GD2#'.03'P3(G^20'03(GZ2,'N&TC!X@5("?*)TDD!T$R)
MTDG!Z@)(P>(>18G&20G22(N4)"`"``!,B?9(P>X;2`'"3`'B28G,B<E-,=1%
M,>5.C20J3(GR2,'B!4@)\DB+M"0H`@``B=))`=1,B?I(`<9)P>\"2,'B'D6)
MY4P)^D@!\4R)UD6)TD@QUD$Q\$R)[DD!R$R)Z4C![AM(P>$%2`GQB<E)`<A,
MB?%)P>X"2,'A'D6)QTD)SDB+C"0P`@``3(G^2,'N&T@!P4P!T4F)THG233'R
M13'43HT4(4R)^4C!X05("?%,B>Y)P>T"B<E(P>8>20'*2(N,)#@"``!,">Y%
MB=1(`<%(`<I,B?%%B?9(,?%!,<A,B>%)`=!,B>)(P>D;2,'B!4@)RDB)\8GV
MB=))`=!,B?I(P>(>2<'O`D6)Q4D)UTB+E"1``@``3#'Y2`'"03'*3(GI3`'R
M2,'I&TD!TDR)ZDC!X@5("<I,B>%)P>P"B=)(P>$>20'22(N4)$@"``!,">%%
MB?Q%B=9(`<)(`?),B?Y(,<Y!,?!*C30"3(GR38GP2<'H&TC!X@5,"<*)TD@!
MUDR)ZDG![0)(P>(>08GP20G52(N4)%`"``!(`<),`>))B<R)R4TQ[$4QXDZ-
M)!),B<)-B<))P>H;2,'B!4P)THG220'43(GR2<'N`DC!XAY%B>),"?),B[0D
M6`(``$D!QDP!\4V)[D6)[4DQUD0Q]DV)UD@!SDR)T4G![AM(P>$%3`GQB<E(
M`<Y,B<%)P>@"2,'A'D&)]DD)R$B+C"1@`@``2`'!20'-2(G1B=),,<%!,<Q+
MC4PE`$V)]$V)]4G![1M)P>0%30GL38G52<'J`DG!Y1Y%B>1-">I,BZPD:`(`
M`$P!X4&)S$D!Q4P!ZDV)Q46)P$TQU40Q[DR-+#),B>),B>9(P>(%2,'N&T@)
M\HG220'53(GR2<'N`DC!XAY$B>Y)"=9(BY0D<`(``$@!PD@#A"1X`@``3`'"
M38G033'P1#'!28GP2`'*2(GQ2<'H&TC!X05,"<%%B=`!T4R)XDG![`)(P>(>
M20G42HT4"$B)R$D!T$R)\DC!X`5$`>-,,>)(B5\803'52XT4*$F)R`'I2<'H
M&TB)3PA,"<`!T$B)!TB)\$C![@)(P>`>2`G&00'S1`-W($R)7Q!,B7<@2(N$
M)(@"``!D2"L$)2@```!U$DB!Q)@"``!;74%<05U!7D%?P^A$Y/__#Q]``$%7
M059!54%455-(@^P(2(7_#X2Q````3(LM,H4``$V%[0^$H0````^V!TF)_TB)
M]83`=`0\/75813'V38ME`$V%Y'0R36/V3(GK9@\?1```3(GR3(G^3(GGZ#+C
M__^%P'4'0X`\-#UT1TR+8PA(@\,(387D==I(@\0(3(G@6UU!7$%=05Y!7\,/
M'X0``````$F)_D$/MD8!28/&`83`=`0\/77O12G^ZY(/'X``````3"GK3XUD
M-`%(P?L#B5T`Z[4/'X``````13'DZZD/'P!52(G^2(G]OP$```!(@>R@````
M9$B+!"4H````2(F$))@````QP$B)XNABY?__A<!U-HM4)!B!X@#P``"!^@!`
M``!T"('Z`*```'4>O@(```!(B>_H]^3__X7`#Y3`#[;`ZP</'T0``#'`2(N,
M))@```!D2"L,)2@```!U"4B!Q*````!=P^CEXO__#Q]$``!!5D%505154TB!
M[*````!D2(L$)2@```!(B80DF````#'`2(7_=`B`/P!(B?UU,4B+A"28````
M9$@K!"4H````#X4I`0``2('$H````%M=05Q!74%>PV8N#Q^$``````#H&^+_
M_TF)Q$B%P'3"28GE3(GGZ#CD__](A<`/A*\```"`>!,N2(U8$W4-@'L!`'3?
M#Q^``````(!X$RX/A*8```!(B>_H)N+__TB)WTF)QN@;XO__08U\!@)(8__H
M+N/__TF)V4F)Z+X!````28G&2(G',<!(Q\+_____2(T-\2```.AXY/__OP$`
M``!,B>I,B?;H>.'__TR)]X/X_W00BT0D&"4`\```/0!```!T6.@+X?__3(GW
MZ./@__],B>?HB^/__TB%P`^%4____V:03(GGZ!CB__](B>_H@.'__^GJ_O__
M#Q\`@'L!+@^%4/___X![`@`/A!3____I0?___P\?@`````#HD_[__^NFZ&SA
M__]F9BX/'X0``````)!(@^P(BSU&@@``Z%'B__^+/3N"``#H1N+__TB+%?=_
M``!(C0UP70``2(TU*R```$B)Q^AIXO__BST3@@``Z![B__],C06V(0``13')
M2(T5K1L``$B)QTR)P4B--18@``!(@\0(Z8?B__\/'X``````54B)_>C7X/__
M2(U4!?](.=5R%NF1````#Q^$``````!(@^H!2#G5="6`.B]T\D@YU7-V2(/J
M`4@YU702#Q]``(`Z+W0H2(/J`4@YU77R@'T`+W1<2(T]PA\``%WI[^+__P\?
M@`````"`.B]U"4B#Z@%(.=5R\D@IZC'`2(U*`DB!^0`0``!W'TB#P@&Y`!``
M`$B)[DB-/<6!``#HP.'__TB-!;F!``!=PT@YU76_ZYY(C3UD'P``7>F3XO__
M#Q\`05=!5D%505152('L`!```$B##"0`2(/L$+K_#P``9$B+!"4H````2(F$
M)`@0```QP$F)Y4B)_4F)]$B-/1X?``!,B>[H5]___X7`?GN-4/]$BSW)@```
M3&/R0H`\-`!U7X72=&I,B?*^+P```$R)[^A;X/__2(7`=%5$B?_HKN#__TR)
M\4R)ZDB)[DB)Q^B=X?__2(N$)`@0``!D2"L$)2@```!U04B!Q!`0``!=05Q!
M74%>05_#9@\?A```````3&/PZZ`/'P!$BSU1@```1(G_Z%G@__],B>)(B>Y(
MB<?HB]___^NLZ$3?__\/'T``05=!5D%505152(GU4TB)^TB#[!AD2(L$)2@`
M``!(B40D"#'`,<"`/CT/E,!(`<5(B>_H^=[__TB-="0$2(G?28G$,<#HM_K_
M_TB%P`^$!@$``$B)QTF)Q>C3WO__23G$#X;2````3&-T)`1)P>8##[8#A,`/
MA)X!```\/0^$E@$``$B)V`\?``^V4`%(@\`!A-)T!8#Z/77O2"G82)A*C7P@
M`DP#-:9_``#HH=___TF)!DB%P'1:2(L%DG\``$AC5"0$2(U+`4B+%-`/M@.(
M`H3`="$\/74,ZQMF#Q]$``"$P'01#[8!2(/"`4B#P0&(`CP]=>O&`CTQP&8/
M'T0```^V3`4`B$P"`4B#P`&$R77O2(M$)`AD2"L$)2@````/A0<!``!(@\08
M6UU!7$%=05Y!7\,/'T``,<!F#Q]$```/ME0%`$&(5`4`2(/``832=>[KO0\?
M0`!,BSWQ?@``28,_``^$M@```$R)^$4Q[9!(@\`(1(GJ08/%`4B#.`!U[XUR
M`TAC]DC!Y@.+!?]^``"%P'5;QP7Q?@```0```$B)]^BIWO__2(7`#X1A____
M36/U3(G^2(G'2<'F`TR)\N@[W___2(D%A'X``$B)P4&-10%(F$C'!,$`````
M1(EL)`3IB/[__V8/'X0``````$R)_^CHWO__2(D%47X``$B)P4B%P`^$!O__
M_TUC]4G!Y@/KNP\?0``QP.E__O__OA````!%,>WI7____^@/W?__9F8N#Q^$
M```````/'T``2(/L"(L]YGT``.CQW?__2(L5HGL``$B#Q`A(C0T760``2(G'
M2(TUSQL``.D0WO__05154TB![``0``!(@PPD`$B![``0``!(@PPD`$B#["!D
M2(L$)2@```!(B80D&"```#'`2(VL)!`0``!)B>3H#=S__TR-#<`;``"Z`1``
M`$B)[T&)P$B-#;(;``"^`0```#'`Z.C>__^Z`!```$R)YDB)[^C(V___13'`
MA<!X+HUX`4B)PTAC_^A3W?__28G`2(7`=!A(8]M,B>9(B<=(B=KH"MW__\8$
M&`!)B<!(BX0D&"```&1(*P0E*````'4/2('$("```$R)P%M=05S#Z/S;__]F
M9BX/'X0``````)#I&____V9F+@\?A```````05=!5D%505154TB![``0``!(
M@PPD`$B![+@```!D2(L$)2@```!(B80DJ!```#'`2(G]28GU2(T][1H``$B-
M="0,Z%GW__^^+P```$B)[TB)P^BIV___2(7`=$0QP$B)[DB-/<L:``#H,_S_
M_TB)Z$B+G"2H$```9$@K'"4H````#X6&`0``2('$N!```%M=05Q!74%>05_#
M#Q^``````$B)[^@HV___2(TUD1H``$R)[T&)Q.@6W?__28G&2(7`=)I!@#X`
M3(TM/AH```^$W@````\?1```2(7;=!-,B?9(B=_HN-O__X7`#X2=````3(GW
MZ-C:__^-4/^)P4ACPDP!\(`X+W4;#Q^$``````")T8/J`<8``$ACPDP!\(`X
M+W3M0HU$(0$]_P\```^/*?___TV)\+H`$```O@$````QP$R-O"2@````2(/L
M"$B-#>H:``!53(T-L!D``$R)_^C[W/__2(U4)"!,B?Z_`0```.CYV?__6EF%
MP'40BT0D*"4`\```/0"```!T4TB--:P9```Q_^@UW/__28G&2(7`#X2U_O__
M08`^``^%)____TB%VW0%@#LN=!5-B>ZY`0```.E;____#Q^$``````"`>P$`
M=+?KXP\?A```````O@$```!,B?_HT]O__X7`=9Q,B?Y(C3TX&0``Z*#Z__],
MB?_H.-S__^EC_O__Z,[9__]F9BX/'X0```````\?``^V!TF)^(3`=!=F#Q]$
M``!(@\<!/"\/M@=,#T3'A,!U[TR)P,-F9BX/'X0``````$B%_W0+@#\`=`;I
MD?C__Y!(C3VD&```Z=3;__\/'T``55-(C1W)&```2(/L2&8/;P6K50``9$B+
M!"4H````2(E$)#@QP#'`2(UL)`P/$40D$&8/;P6750``9HE$)#`/$40D(`\?
M1```,<!(B>Y(B=_HV_3__TB%P'0^2&-4)`Q(BP4:>@``2(T$T$B+4`A(B1!(
MA=)TTF8N#Q^$``````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(C1T\&```
MD#'`2(GN2(G?Z(/T__](A<!T-DAC5"0,2(L%PGD``$B-!-!(BU`(2(D02(72
M=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-'?07``"0,<!(B>Y(B=_H
M,_3__TB%P'0V2&-4)`Q(BP5R>0``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#
MP`A(B1!(A=)U\.N^9@\?1```2(T=K1<``)`QP$B)[DB)W^CC\___2(7`=#9(
M8U0D#$B+!2)Y``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7P
MZ[YF#Q]$``!(C1UD%P``D#'`2(GN2(G?Z)/S__](A<!T-DAC5"0,2(L%TG@`
M`$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B-
M'207``"0,<!(B>Y(B=_H0_/__TB%P'0V2&-4)`Q(BP6">```2(T$T$B+4`A(
MB1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```2(T=BQ8``)`QP$B)
M[DB)W^CS\O__2(7`=#9(8U0D#$B+!3)X``!(C0302(M0"$B)$$B%TG329I!(
MBU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(C1V0%@``D#'`2(GN2(G?Z*/R__](
MA<!T-DAC5"0,2(L%XG<``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D0
M2(72=?#KOF8/'T0``$B-'4H6``"0,<!(B>Y(B=_H4_+__TB%P'0V2&-4)`Q(
MBP62=P``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?
M1```2(T=!!8``)`QP$B)[DB)W^@#\O__2(7`=#9(8U0D#$B+!4)W``!(C030
M2(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(C1U4%0``
MD#'`2(GN2(G?Z+/Q__](A<!T-DAC5"0,2(L%\G8``$B-!-!(BU`(2(D02(72
M=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$B)[DB-/6L5``#H:?'__TB)
MQDB%P'0.2(T]0Q4``#'`Z%/V__](B>Y(C3U7%0``,<#H0O'__TB)QDB%P'0.
M2(T]4Q4``#'`Z"SV__](B>Y(C3U-%0``,<#H&_'__TB)QDB%P'0Z2(T]EA0`
M`#'`Z`7V__\QP$B--?P5``!(C3VX%```Z/#U__](BT0D.&1(*P0E*````'51
M2(/$2%M=PTB)[DB-/0H5```QP.C(\/__2(G&2(7`=!!(C3V8%```,<#HLO7_
M_^NK2+A005)?0TQ%04@Y1"0A=9IF@7PD*4X]=9%(C70D*^O/Z,K4__]F+@\?
MA```````2(/L&&1(BP0E*````$B)1"0(BP5X=0``@_C_=!M(BWPD"&1(*SPE
M*````'5"2(/$&,-F#Q]$``!(C70D!$B-/1L4```QP.@U\/__2(G",<!(A=)T
M$@^V$H#Z,`^5P3'`A-(/E<`AR(D%(W4``.NNZ$S4__]F9BX/'X0``````)!(
M@^P(Z$?4__^)Q^CPT___2(7`=`-(BP!(@\0(PP\?`$%454B)_4B-/2H4``!3
M2(/L$&1(BP0E*````$B)1"0(,<!(C70D!.BT[___2(7`=`B`.`!(B<-U-TB+
M1"0(9$@K!"4H````#X6Y````2(GN2(/$$$B-/=P3```QP%M=05SI>O3__V8N
M#Q^$``````!(B>Y(B<?H%=;__TB%P'0@2(M$)`AD2"L$)2@```!U=DB#Q!!;
M74%<PP\?@`````!(B>_H:-/__TB)WTF)Q.A=T___28U\!`+H<]3__TB#[`A)
MB>B^`0```%-(Q\+_____2(G'28G$3(T-HA(``$B-#9H3```QP.BTU?__6%I(
MBT0D"&1(*P0E*````'4(3(GFZ4K____H%=/__P\?1```2(/L"+^`````Z!+4
M__^ZB:O-[[G^W+J8OO#ATL-(QP`!(T5G2(E0"$B)2!!(QT`8=E0R$$B)<"!(
MQT`H`````$C'0#``````QT!X`````$B#Q`C#9F8N#Q^$``````"005152(G]
M4TB#[!!D2(L$)2@```!(B40D"#'`2(7_#X2\````@#\`#X2S````Z([Q__\/
MMA!(B<.$TG06#Q]``$B#P`&`^B\/MA!(#T38A-)U[HL%*',``$B%[4$/E<2#
M^/\/A)````"%P`^5P$$AQ$6$Y'4C2(M$)`AD2"L$)2@````/A;````!(@\00
M6UU!7,-F#Q]$``"`?0``=->Y!````$B-/2T2``!(B=[SI@^7P!P`A,!UO4B+
M1"0(9$@K!"4H````=7%(@\002(GO6UU!7.GX[O__#Q^$``````!(C3WT$```
MZ"34___I0?___P\?@``````QP$B-="0$2(T]21$``.AE[?__2(7`=`L/M@"$
MP'0$/#!U#\<%6W(```````#I2____\<%3'(```$```#I-____^ART?__9I!!
M5TACPD%628G&055!5$F)_%5(C6\X4TB)\TB#[`A(BW<H2(M7,(T,QD@Y\4B)
M3RA(@](`2,'H'4@!T$B)1S!(8T=XA<`/A>T```!!@_X_#XXK`0``08/N0$6)
M]T'![P9%C6\!2<'E!DD!W0\?1```\P]O`TR)YTB#PT`/$44`\P]O2]`/$4T0
M\P]O4^`/$54@\P]O6_`/$5TPZ''6__],.>MUS$'!YP9%*?Y)8\9(@_@(<EQ)
MBU4`28E4)#A)BU0%^$B)5`7X2(U5"$B#XOA(*=5)*>U(`<5(@^7X2(/]"'(8
M2(/E^#'`28M,!0!(B0P"2(/`"$@YZ'+N18ET)'A(@\0(6UU!7$%=05Y!7\-F
MD*@$=71(A<!TX4$/ME4`08A4)#BH`G3300^W5`7^9HE4!?[KQ@\?0`!!O4``
M``!(C7P%`$B)WD$IQ44Y[D4/3NY-8_U,B?KH]=#__T&+1"1X1`'H08E$)'B#
M^$!UDDR)YT4I[DP!^^B5U?__Z<O^__])B=WI(____T&+50!!B50D.$&+5`7\
MB50%_.E;____D$%63(UV.$%505152(GU4TB+1BA(B?M$BV8H1(MN,$C!Z`.#
MX#]!#\Q!#\V-2`%(F,9$!CB`2&/!3`'P@_DX#XXD`0``OD`````ISG0/,=*)
MT8/"`<8$"``Y\G+S2(GOZ`S5__]F#^_`#Q%%.$G'1C``````00\11A!!#Q%&
M($2);7!(B>]$B65TZ.+4__](BT4`2(GO2,'H&(@#2(M%`$C!Z!"(0P%(BT4`
M2,'H"(A#`DB+10"(0P-(BT4(2,'H&(A#!$B+10A(P>@0B$,%2(M%"$C!Z`B(
M0P9(BT4(B$,'2(M%$$C!Z!B(0PA(BT402,'H$(A#"4B+11!(P>@(B$,*2(M%
M$(A#"TB+11A(P>@8B$,,2(M%&$C!Z!"(0PU(BT482,'H"(A##DB+11B(0P](
MBT4@2,'H&(A#$$B+12!(P>@0B$,12(M%($C!Z`B(0Q)(BT4@B$,36UU!7$%=
M05[IB\W__P\?`+HX````,?\IRH/Z"')*B=%(QP``````2,=$"/@`````2(U(
M"$B#X?A(*<@!PH/B^(/Z"`^"W?[__X/B^#'`B<:#P`A(B3PQ.=!R\^G&_O__
M#Q^$``````#VP@1U(X72#X2Q_O__Q@``]L("#X2E_O__,<EFB4P0_NF9_O__
M#Q\`QP``````QT00_`````#I@_[__P\?1```05=!5D%505154TR-G"0`@/__
M2('L`!```$B##"0`3#G<=>](@>Q8`0``9$B+!"4H````2(F$)$B!``!(C07,
M#0``2(UL)!Q)B?U(C3W)#```2,=$)%``````2(GN2,>$)(@`````````2,=$
M)#``````2(E$)$!(C05]#```2(E$)$A(C04?#0``2(E$)&A(C05]#0``2(E$
M)'!(C04D#0``2(E$)'A(C05M#0``2(F$)(````!(C05%#0``2(E$)"!(C056
M#0``2(E$)"@QP.B[Z/__2(7`=`R`.`!)B<0/A:H$``#H]<S__XG'Z)[,__](
MA<`/A/4#``!,BR!-A>0/A.D#``!,B>?HL<S__TB-?``!Z,?-__]%#[8$)$B)
MPT6$P'0U28G?3(TU^`P``$R)_TR)\4C'PO____\QP+X!````28/$`4F#QP+H
M_\[__T4/M@0D183`==5,C70D8$B-/4D,``#K&`\?@`````!)BWX(28/&"$B%
M_P^$-P$``$B)[C'`Z`7H__])B<1(A<!TW8`X`'382(G'Z,#H__^%P'3,3(GG
MZ(3.__])B<=(A<`/A``!```/'X0``````$R)_^CXR___2(G?28G$Z.W+__]%
MC;0$!`0``$UC]DR)]^CZS/__4TV)^$R-#0P+``!)B<1(C07\"P``O@$```!(
MQ\+_____4$B-#1X,``!,B><QP.@WSO__3(GGOL`!``#H"LO__U]!6(/X_W42
MZ,W*__]$BPA!@_D1#X4D`P``3(V\))````!,B>:_`0```$R)^NB8S?__B<.%
MP`^$O@```$F+30!(BSV3;```38G@,<!(C15?#```O@$```!%,?;HFLW__TB+
MA"1(@0``9$@K!"4H````#X7%!0``2('$6($``$R)\%M=05Q!74%>05_#9@\?
M1```3(MD)$!%,?;K$V8/'T0``$ECQDR+9,1`387D=#M!@#PD`'0T3(GG08/&
M`>AXY___A<!TW$R)Y^@\S?__28G'2(7`#X7`_O__26/&3(MDQ$!-A>1UR`\?
M`$4Q_^FH_O__#Q^$``````"+A"2H````)0#P```]`$````^%*____XN$)*P`
M``")1"0(Z)G*__\Y1"0(#X41____BX0DJ````"7_`0``/<`!```/A?K^__],
MB??H<,O__TB-/7L*``!(B>Y)B<8QP.@,YO__2(G'2(7`#X1``@``Z)O,__])
MBWT`2(G&Z$_N__])B<!(A<`/A","``!,B<=,B40D".@&RO__3(M$)`B#^`-^
M/$ACT+D%````2(T]8PH``$F-=!#\\Z8/E\*`V@"$TG4<@_@$#X3!`P``@^@%
M2)A!@#P`+P^$L0,```\?`(L%FFH``(/X_P^$60,``(7`#X3,`0``2(TU<@H`
M`$B-/4H)```QP.ADZO__2(TM/`H``$R-+<,(``#H$<G__U5(Q\+_____38G@
M4$R-#:L(``"^`0```$R)]TB-#>X)```QP.CHR___6%KK1`\?0`#HB\C__X,X
M$75(Z-'(__^#PP%(@^P(38GI54V)X$B-#<D)``"^`0```%-(Q\+_____3(GW
M4#'`Z*3+__](@\0@OL`!``!,B??H<\C__X/X_W2N3(GGZ";(__],B?9(C3U&
M"```,<#HM>G__TR)]^C-]/__Z9[]__\/'X0``````#';2(T]"0D``.L2#Q]$
M``!(8\-(BWS$($B%_W0X2(GN,<"#PP'H=N3__TB%P'3A@#@`=-Q(B<?H!,O_
M_TF)Q$B%P`^%S_O__TACPTB+?,0@2(7_=<B_#0```$R-);8(``#HBLG__T&X
M4P```$B)P^G"^___28M-`$B+/9%I``!-B>`QP$B-%1T)``"^`0```$4Q]NB8
MRO__Z?G\__\/'P!(B<?H&/3__TB+A"1(@0``9$@K!"4H````#X6S`@``2('$
M6($``$R)YUM=05Q!74%>05_I:,K__P\?A```````38M%`.G4_?__QP6]:```
M`````#'V3(G',<#HD<G__XG%A<`/A![^__^Z`@```$C'QN[___^)Q^@$RO__
M2(V<)$`!``"Z!@```(GO2(G>Z%W(__^`O"1``0```'4.@+PD00$``$,/A+\!
M```QTC'VB>_HRLG__[^`````Z)#(__](QP`!(T5G28G%N(FKS>])B44(2"V+
MSA)728E%$$@%\@08*TG'11AV5#(028E%($G'12@`````2<=%,`````!!QT5X
M`````.L4#Q^``````(G"2(G>3(GOZ+/U__^Z`(```$B)WHGOZ,3'__^%P'_@
MB>](C9PD(`$``$B-+5<'``#H6L?__TR)[DB)WTF)W>@<]___2(V$)+@```!,
MB?M(B40D"`\?0`!%#[9%`$B)WTB)Z;X!````2,?"_____S'`28/%`4B#PP+H
M,LG__T@Y7"0(==-(C05#!P``QH0DN`````!005=(C0T"!P``38G@3(GW,<"^
M`0```$R-#:L%``!(Q\+_____Z/+(__]97NE=_?__#Q\`,<!(B>Y,B40D"$B-
M/?8%``#H$N+__TR+1"0(2(7`#X1-_O__#[8`A,`/A$+^__\\,`^$.O[__\<%
M]V8```$```#I:?S__TV+;0A-A>T/A$7\__],B>],B40D".CXQ?__3(M$)`A(
M@_@##X8I_/__28UT!?RY!0```$B-/5,&``#SI@^7P!P`A,!-#T3%Z0;\__^`
MO"1"`0``00^%,_[__X"\)$,!``!##X4E_O__@+PD1`$``$@/A1?^__^`O"1%
M`0``10^%"?[__[H"````2,?&QO___XGOZ,O'__^Z*0```$B)WHGOZ"S&__](
MC044!@``4%/IU?[__^AIQ?__9@\?A```````055!5%5(@^P0BSU!9@``9$B+
M!"4H````2(E$)`@QP.@\QO__BSTF9@``2(G%Z"[&__\/MI6X````2(UL)`1(
MC3V>!```2(GNB)"Y````,<#HR^#__TB%P'0)@#@Q#X2U`0``,<#HANO__XL]
MX&4``.CKQ?__N0,```"Z`0```$B--7@%``!(B<?HHL7__TF)Q$B%P'0X2(M`
M$(L]L&4``$R+*.BXQ?__2(T5404``$B)QTR)[NCFQ/__28M$)!!,BR!!]D0D
M#D`/A9(!``"+/7QE``#HA\7__[D#````N@$```!(C34;!0``2(G'Z#[%__])
MB<1(A<!T/DB)[DB-/:\#```QP.@5X/__28G%2(7`#X09`0``28M$)!"+/2YE
M``!,BR#H-L7__TR)ZDB)QTR)YNAHQ/__BST290``Z!W%__^Z`0```$B--;@$
M``!(B<?H*<7__XL]\V0``$F)Q.C[Q/__3(GF2(T5K00``$B)Q^@IQ/__BSW3
M9```Z-[$__](B>Y(C3T>`P``QH"Y`````#'`Z(;?__](B04W=0``28G$2(7`
M=#^^P`$``$R)Y^@*P___C5`!@_H!=@F#^!$/A;0```!(BT0D"&1(*P0E*```
M``^%O0```$B#Q!!=05Q!7<,/'P!(BSWQ=```Z)SU__](B07==```28G$2(7`
M=:9(C3VV!```,<#H?\3__P\?@`````"`>`$`#X1(_O__Z3S^__]F#Q^$````
M``!(BP6I=```BST39```3(LH28M$)!!,BR#H$\3__TR)[DR)Y^C8XO__Z=O^
M__\/'P"+/>IC``#H]</__TR)YDB)Q^A*Q/__Z5/^__^)P4B+!5QT``!,B>)(
MC3U:!```2(LP,<#H^,/__^C#PO__#Q\`\P\>^D%73(T],U\``$%628G6055)
MB?5!5$&)_%5(C2TD7P``4TPI_4B#[`CH?\'__TC!_0-T'S';#Q^``````$R)
M\DR)[D2)YT'_%-](@\,!2#G==>I(@\0(6UU!7$%=05Y!7\-F9BX/'X0`````
M`/,/'OK#9BX/'X0``````)#S#Q[Z2(L-_6(``.FPPO__\P\>^DB#[`A(@\0(
MPP``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!)
M;G1E<FYA;',Z.E!!4CHZ0D]/5``N`"\`+W!R;V,O<V5L9B]E>&4`+W!R;V,O
M)6DO)7,`4$%27U1%35``4$%27U!23T=.04U%`#H`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`$Q$7TQ)0E)!4EE?4$%4
M2`!P87(M`"UE`"TM`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%
M4DY!344`)3`R>``E<R5S)7,E<P!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`
M)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ
M4&%C:V5R.CI615)324].`#$N,#4Q`````````"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````
M```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A
M<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R
M;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R
M('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L
M("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H
M:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@
M6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*
M>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@
M+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@
M)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@
M)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N
M9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N
M86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF
M(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD4$%27TU!1TE#(#T@
M(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I
M970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3
M,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A
M<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L
M("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O
M9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1P<F]G;F%M93L*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0[
M"FUY("1M86=I8U]P;W,["FEF("@D<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD
M;6%G:6-?<&]S(#T@,#L*?2!E;'-I9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU
M;FM?<VEZ92D@/B`P*2!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L
M<V4@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL
M92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96LH7T9(+"`D;6%G:6-?<&]S+"`P
M*3L*<F5A9"A?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?
M34%'24,I*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#
M*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P
M;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U
M9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T
M.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,
M12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5
M;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@
M/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L
M<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D
M8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL
M96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@
M/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F
M(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*
M?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY
M("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE
M(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R
M+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I
M;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D
M:6YF;RT^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D:6YF;RT^>V-R8WTN
M<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA
M;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E
M*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE
M9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM
M>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2![
M"G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$
M4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER
M92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I
M;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R
M97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q
M(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@
M("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.
M5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q
M("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@
M<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS
M=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`
M05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6
M.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![
M(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL
M92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI
M*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?
M:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B([
M"GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q
M(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G
M0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*
M)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H
M+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2([
M"GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H
M:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*
M?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*
M>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q
M=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM
M>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L
M("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D
M92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D
M("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP
M(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2![
M"B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M
M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L
M("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@
M)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P
M87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S
M7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE
M+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ
M3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@
M9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S
M*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L
M;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA
M<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`]
M(")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")0
M05)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I
M8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@
M;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O
M(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1?
M?2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII
M9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL
M92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI
M*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE
M;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY
M("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D
M:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL
M87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A0
M86-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L
M"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G
M/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM
M;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D
M960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@
M/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO
M=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%
M(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D[
M"B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O
M;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D
M>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`[
M"FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I
M*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM
M>2`D9F@L("(\(BP@)&]U="D["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL
M92@D9F@I.PIC;&]S92@D9F@I.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I
M9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C
M86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I
M.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D[
M"G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA
M;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A
M.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@
M<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB
M97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER
M96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ
M<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI
M.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]
M"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD[
M"GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$
M>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR
M97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N
M=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ
M2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:
M;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(
M03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!0
M05(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB
M=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I
M;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@
M<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I
M<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@
M4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U
M:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I
M('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H
M("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$
M25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P
M871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@
M/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H
M)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO
M9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE
M(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%
M?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S
M+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R
M;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B
M=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X
M+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]
M"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI3
M2$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F
M:"P@(CPB+"`D<')O9VYA;64I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M
M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E
M<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`]
M(#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD
M14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@
M>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL
M;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M
M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D
M9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N
M86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC
M;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D
M;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH
M)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R
M;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D
M14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q
M.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@
M:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O
M9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-
M17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I
M('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@
M:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O
M<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L
M("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@
M86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF
M:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH
M*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL
M(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C
M=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W
M9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD
M<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D
M<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])
M3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[
M4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0
M($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6
M>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"
M54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P
M87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B
M.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.
M?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2![
M"FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B
M0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O
M7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D
M<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE
M;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER
M92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I
M9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E
M87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP
M"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#
M+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I
M92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M
M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P
M<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z
M.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ
M7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T52
M4D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*`````'!E<FQX<VDN8P``
M`````````````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M`1L#.P0!```?````H(+__S@!```@AO__8`$``#"&__]0!0``0(C__R`!```P
MB?__>`$``%"?___(`0``(*#__Q0"``"PH/__.`(``#"B__]\`@``H*+__Y0"
M``!@H___O`(``%"D__\$`P``D*;__U`#``#`IO__:`,``*"G__^D`P``L*?_
M_[@#``#0J?__'`0```"J__\P!```(*K__T0$``#0KO__<`0``%"O__^,!```
M<*___Z0$``"`L/__]`0``."P__\,!0``(++__WP%``#`L___R`4``,"U__\(
M!@``,+[__^0&``#0P/__&`<``$#!__]@!P``4,'__W@'````````%```````
M```!>E(``7@0`1L,!PB0`0``%````!P````8A___+P````!$!Q``````)```
M`#0```!@@?__@`,````.$$8.&$H/"W<(@``_&CLJ,R0B`````!0```!<````
MN(3__P@``````````````$P```!T````L(?__QP6````0@X0CP)&#AB.`T(.
M((T$0@XHC`5!#C"&!D$..(,'1P[0!0/W%0H..$$.,$$.*$(.($(.&$(.$$(.
M"$$+````2````,0```"`G?__S0````!"#A"/`D(.&(X#0@X@C01"#BB,!4$.
M,(8&00XX@P=$#D`";`H..$0.,$$.*$(.($(.&$(.$$(."$D+`"`````0`0``
M!)[__XL`````00X0A@)2#K`!`G$*#A!!#@A!"T`````T`0``<)[__W0!````
M0@X0C@)"#AB-`T(.((P$00XHA@5!#C"#!D<.T`%^"@XP00XH00X@0@X80@X0
M0@X(2PL`%````'@!``"LG___:0````!$#A`"8`X()````)`!```$H/__O0``
M``!!#A"&`@);"@X(3`L"0`H."$$+3PX(`$0```"X`0``G*#__^P`````0@X0
MCP)"#AB.`T(.((T$0@XHC`5!#C"&!D<.L"!)#L`@`I0*#C!!#BA"#B!"#AA"
M#A!"#@A*"T@``````@``1*'__S$"````0@X0CP)"#AB.`T(.((T$0@XHC`5!
M#C"&!D0..(,'1PY0`Q4!"@XX00XP00XH0@X@0@X80@X00@X(10L4````3`(`
M`#BC__\P`````$0.$%8."``X````9`(``%"C___4`````$(.$(P"00X8A@-!
M#B"#!$<.H"!,#J!`20[`0`*G"@X@1`X800X00@X(00L0````H`(``/2C__\%
M`````````&````"T`@``\*/__Q("````0@X0CP)"#AB.`T(.((T$0@XHC`5!
M#C"&!D$..(,'1PZX($P.\"$"<0H..$$.,$$.*$(.($(.&$(.$$(."$@+`JX.
M^"%(#H`B8@[X(4$.\"$````0````&`,``*RE__\E`````````!`````L`P``
MR*7__QP`````````*````$`#``#4I?__I@0```!!#A"&`D$.&(,#2PY@`T<$
M"@X800X000X(00L8````;`,``%BJ__]T`````$0.(&T*#@A'"P``%````(@#
M``"\JO__'0````!$#A!8#@@`3````*`#``#$JO__"P$```!"#A",`D$.&(8#
M2PX@@P1$#C`"0@H.($H.&$$.$$(."$\+9`H.($$.&$$.$$(."$@+80XX20Y`
M8PXX00XP```4````\`,``(2K__]4`````$0.$`)/#@A`````"`0``,RK__\^
M`0```$(.$(P"00X8A@-$#B"#!$0.,`*""@X@00X800X00@X(1PMT"@X@1`X8
M00X00@X(30L``"@```!,!```V(#__P\"````0@X0C`)!#AB&`T0.4`.D`0H.
M&$0.$$(."$$+2````'@$``"<K/__GP$```!"#A"/`D4.&(X#10X@C01"#BB,
M!40.,(8&10XX@P='#D`"Y0H..$$.,$$.*$(.($(.&$(.$$(."$,+`#P```#$
M!```\*W___L!````0@X0C@)&#AB-`T(.((P$00XHA@5$#C"#!@-*`0H.*$$.
M($(.&$(.$$(."$@+``#8````!`4``+"O__]G"````$(.$(\"0@X8C@-"#B"-
M!$(.*(P%00XPA@9!#CB#!T@,"[B``E$-!T<.D(,"`[T!#IB#`F$.H(,"7PZ8
M@P)"#I"#`@)["@XX1`XP00XH0@X@0@X80@X00@X(1PL#B`$.F(,"2PZ@@P)>
M#IB#`D$.D(,"7`Z8@P)$#J"#`E`.J(,"2PZP@P)+#I"#`@,&`0H..$0.,$$.
M*$(.($(.&$(.$$(."$T+`V4!#IB#`D(.H(,":`Z8@P)!#I"#`@+\"@Z8@P)!
M#J"#`D4+````,````.`%``!$M___G0(```!"#A"-`D(.&(P#00X@A@1$#C`#
MU@$*#B!!#AA"#A!"#@A$"T0````4!@``L+G__V4`````1@X0CP))#AB.`T4.
M((T$10XHC`5$#C"&!D@..(,'1PY`;@XX00XP00XH0@X@0@X80@X00@X(`!0`
M``!<!@``V+G__P4``````````````!````!T!@``T+G__Q``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````"@)@```````&`F`````````0````````#R`@``
M``````$`````````_0(````````!``````````T#````````'0````````"8
M!`````````P``````````"`````````-`````````.!>````````&0``````
M``"0O0```````!L`````````"``````````:`````````)B]````````'```
M```````(``````````0`````````"`,```````#U_O]O`````*`%````````
M!0````````"X#P````````8`````````H`8````````*`````````,T$````
M````"P`````````8`````````!4````````````````````#``````````#`
M`````````@`````````H!0```````!0`````````!P`````````7````````
M`$@7````````!P````````#(%0````````@`````````@`$````````)````
M`````!@`````````^___;P`````````(`````/[__V\`````2!4```````#_
M__]O``````(`````````\/__;P````"&%````````/G__V\`````!```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"@O0`````````````````````````````V(````````$8@
M````````5B````````!F(````````'8@````````AB````````"6(```````
M`*8@````````MB````````#&(````````-8@````````YB````````#V(```
M``````8A````````%B$````````F(0```````#8A````````1B$```````!6
M(0```````&8A````````=B$```````"&(0```````)8A````````IB$`````
M``"V(0```````,8A````````UB$```````#F(0```````/8A````````!B(`
M```````6(@```````"8B````````-B(```````!&(@```````%8B````````
M9B(```````!V(@```````(8B````````EB(```````"F(@```````+8B````
M````QB(```````#6(@```````.8B````````]B(````````&(P```````!8C
M````````)B,````````V(P```````$8C````````5B,```````!F(P``````
M`'8C````````AB,```````"6(P``````````````````V,$```````#_____
M`````.!B````````1T-#.B`H4U5312!,:6YU>"D@,3`N,BXQ(#(P,C`Q,3$W
M(%MR979I<VEO;B`Y.&)A,#-F9F4P8CEF,S=B-#DQ-F-E-C(S.&9A9#<U-&4P
M,&0W,C!B70``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED
M`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU
M+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N
M:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H
M9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC
M`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````
M````````````````````````````````````````````````````````````
M``````````L````!`````@````````"H`@```````*@"````````'```````
M``````````````$````````````````````3````!P````(`````````Q`(`
M``````#$`@```````"0````````````````````$````````````````````
M)@````<````"`````````.@"````````Z`(````````@````````````````
M````!````````````````````#@````%`````@`````````(`P````````@#
M````````F`(````````&``````````@`````````!``````````T````]O__
M;P(`````````H`4```````"@!0```````/P`````````!@`````````(````
M````````````````/@````L````"`````````*`&````````H`8````````8
M"0````````<````!````"``````````8`````````$8````#`````@``````
M``"X#P```````+@/````````S00```````````````````$`````````````
M``````!.````____;P(`````````AA0```````"&%````````,(`````````
M!@`````````"``````````(`````````6P```/[__V\"`````````$@5````
M````2!4```````"```````````<````"````"````````````````````&H`
M```$`````@````````#(%0```````,@5````````@`$````````&````````
M``@`````````&`````````!T````!````$(`````````2!<```````!(%P``
M`````"@%````````!@```!@````(`````````!@`````````?@````$````&
M```````````@`````````"`````````;````````````````````!```````
M`````````````'D````!````!@`````````@(````````"`@````````@`,`
M`````````````````!``````````$`````````"$`````0````8`````````
MH",```````"@(P````````@````````````````````(``````````@`````
M````C0````$````&`````````+`C````````L",````````P.P``````````
M````````$````````````````````),````!````!@````````#@7@``````
M`.!>````````#0````````````````````0```````````````````"9````
M`0````(``````````&``````````8````````(`]```````````````````0
M````````````````````H0````$````"`````````("=````````@)T`````
M```$`0``````````````````!````````````````````*\````!`````@``
M``````"(G@```````(B>````````B`8```````````````````@`````````
M``````````"Y````#@````,`````````D+T```````"0K0````````@`````
M```````````````(``````````@`````````Q0````\````#`````````)B]
M````````F*T````````(````````````````````"``````````(````````
M`-$````&`````P````````"@O0```````*"M````````(`(````````'````
M``````@`````````$`````````"(`````0````,`````````P+\```````#`
MKP```````$`````````````````````(``````````@`````````V@````$`
M```#``````````#``````````+````````#0`0``````````````````"```
M```````(`````````.,````!`````P````````#0P0```````-"Q````````
M(`````````````````````@```````````````````#I````"`````,`````
M`````,(```````#PL0```````)@0```````````````````@````````````
M````````[@````$````P````````````````````\+$```````!6````````
M`````````````0`````````!``````````$````#````````````````````
L`````$:R````````]P````````````````````$`````````````````````
